"""
    :platform: Windows (IronPython)
    :synopsis: Controls the a non-stop head.

    .. moduleauthor:: RJ Bates<rj@junipersys.com>
"""
from HM.Devices.DeviceProperties import PickListValueFormatter
from System.Collections.Generic import List
from System.Threading.Tasks import Task, TaskScheduler, TaskCreationOptions
from System.Threading import CancellationToken
from JS.Common.Units import Unit
from HM.Devices.Scripting import CycleScriptType
from HM.Devices.Scripting import DeviceScriptType
import os

def run_as_task(action):
	return Task.Factory.StartNew(action, CancellationToken.None, TaskCreationOptions.None, TaskScheduler.Default)

class LowYield:
	def __init__(self):
		logger.Debug("Creating Low Yield plugin")
 		self.version = "1.0.1"
		self.Name = "LowYield"

	def initialize(self):
		pass

	def attach_grain_gage(self):
		#Check if this is not a SingleBDS grain_gage and show error
		if grain_gage.Name != "Single BDS HiCap":
			raise ValueError("Low Yield Script is only compatible with Single BDS HiCap only.")
		logger.Info("loading scripts from folder:{0}".format(plugin_root))
		#Plot Script
		plot_script =  os.path.join(plugin_root,"Plot.py")
		logger.Info("loading plot script:{0}".format(plot_script))
		grain_gage.ScriptRunner.LoadCycleScriptFromFile(CycleScriptType.Plot,1,plot_script)
		#Collection Setup Script
		collection_setup_script = os.path.join(plugin_root,"CollectionSetup.py")
		logger.Info("loading collection setup script:{0}".format(collection_setup_script))
		grain_gage.ScriptRunner.LoadDeviceScriptFromFile(DeviceScriptType.CollectionSetup,collection_setup_script)
		#Tare Script
		tare_script = os.path.join(plugin_root,"Tare.py")
		logger.Info("loading tare script:{0}".format(tare_script))
		grain_gage.ScriptRunner.LoadDeviceScriptFromFile(DeviceScriptType.Tare,tare_script)

	def detach_grain_gage(self):
		#Re-load original scripts
		config_root_folder = os.path.join(config_root,"..","SingleBdsHcgg","Scripts")
		logger.Info("restoring device scripts from folder:{0}".format(config_root_folder))
		#plot script
		plot_script =  os.path.join(config_root_folder,"Plot.py")
		logger.Info("loading plot script:{0}".format(config_root))
		grain_gage.ScriptRunner.LoadCycleScriptFromFile(CycleScriptType.Plot,1,plot_script)
		#collection setup script
		collection_setup_script = os.path.join(config_root_folder,"CollectionSetup.py")
		logger.Info("loading collection setup script:{0}".format(collection_setup_script))
		grain_gage.ScriptRunner.LoadDeviceScriptFromFile(DeviceScriptType.CollectionSetup,collection_setup_script)
		#Tare script
		tare_script = os.path.join(config_root_folder,"Tare.py")
		logger.Info("loading collection setup script:{0}".format(tare_script))
		grain_gage.ScriptRunner.LoadDeviceScriptFromFile(DeviceScriptType.Tare,tare_script)


	def handle_enter_press(self):
		pass

	def handle_collection_mode_changed(self, mode):
		pass

	def handle_collection_enabled_changed(self, enabled):
		pass
	
	def refresh_settings(self):
		pass

	def handle_changed_setting(self, setting_name):
		pass

	def handle_key_press(self, key, modifier_keys):
		pass

	def setup_for_collect(self):
		pass

	def post_cycle_hook(self, observer, cycle, completed_cycles, flush):
		pass
	
	def post_plot_hook(self, observer, cycle, completed_cycles):
		pass
		
	def post_script_hook(self, observer, script_type, script_status, error_code, exception):
		pass

	def pre_cycle_hook(self, observer, cycle, completed_cycles, flush):
		pass
		
	def pre_plot_hook(self, observer, current_cycle, cycles_completed):
		pass

	def pre_script_hook(self, observer, script_type):
		pass
